@@ -1,6 +1,5 @@
 from .shape import Shape
 from .reactor import Reactor
-from .utils import define_moab_core_and_tags, add_stl_to_moab_core, export_vtk
 from .utils import rotate, extend, distance_between_two_points, diff_between_angles
 from .utils import EdgeLengthSelector, FaceAreaSelector
 
@@ -91,3 +90,4 @@ from .parametric_reactors.segmented_blanket_ball_reactor import SegmentedBlanket
 from .parametric_reactors.center_column_study_reactor import CenterColumnStudyReactor
 from .parametric_reactors.sparc_paper_2020 import SparcFrom2020PaperDiagram
 from .parametric_reactors.iter_paper_2020 import IterFrom2020PaperDiagram
+from .parametric_reactors.cylinder_reactor import CylinderReactor
