@@ -1,6 +1,5 @@
 
 import numpy as np
-
 from paramak import RotateSplineShape
 
 
@@ -11,61 +10,34 @@ class Plasma(RotateSplineShape):
     Args:
         elongation (float, optional): the elongation of the plasma.
             Defaults to 2.0.
-        major_radius (int, optional): the major radius of the plasma (cm).
-            Defaults to 450.
+        major_radius (float, optional): the major radius of the plasma (cm).
+            Defaults to 450.0.
         minor_radius (int, optional): the minor radius of the plasma (cm).
-            Defaults to 150.
+            Defaults to 150.0.
         triangularity (float, optional): the triangularity of the plasma.
             Defaults to 0.55.
-        vertical_displacement (int, optional): the vertical_displacement
-            of the plasma (cm). Defaults to 0.
-        num_points (int, optional): number of points to described the
+        vertical_displacement (float, optional): the vertical_displacement
+            of the plasma (cm). Defaults to 0.0.
+        num_points (int, optional): number of points to describe the
             shape. Defaults to 50.
         configuration (str, optional): plasma configuration
             ("non-null", "single-null", "double-null").
             Defaults to "non-null".
-        x_point_shift (float, optional): Shift parameters for locating the
+        x_point_shift (float, optional): shift parameters for locating the
             X points in [0, 1]. Defaults to 0.1.
-        Others: see paramak.RotateSplineShape() arguments.
-
-    Keyword Args:
-        elongation (float): the elongation of the plasma.
-        major_radius (int): the major radius of the plasma (cm).
-        minor_radius (int): the minor radius of the plasma (cm).
-        triangularity (float): the triangularity of the plasma.
-        vertical_displacement (int): the vertical_displacement
-            of the plasma (cm).
-        num_points (int): number of points to described the
-            shape.
-        configuration (str): plasma configuration
-            ("non-null", "single-null", "double-null").
-        x_point_shift (float): Shift parameters for locating the
-            X points in [0, 1].
-        outer_equatorial_point (float, float): coordinates for outer
-            equatorial point
-        inner_equatorial_point (float, float): coordinates for inner
-            equatorial point
-        high_point (float, float): coordinates for high point
-        low_point (float, float): coordinates for low point
-        lower_x_point (float, float): coordinates for lower x point (None
-            if doesn't exist)
-        upper_x_point (float, float): coordinates for upper x point (None
-            if doesn't exist)
-        Others: see paramak.RotateSplineShape() attributes.
-
-    Returns:
-        a paramak shape object: A shape object that has generic functionality
-        with points determined by the find_points() method. A CadQuery solid of
-        the shape can be called via shape.solid.
+        name (str, optional): Defaults to "plasma".
+        material_tag (str, optional): defaults to "DT_plasma".
+        stp_filename (str, optional): defaults to "plasma.stp".
+        stl_filename (str, optional): defaults to "plasma.stl".
     """
 
     def __init__(
         self,
         elongation=2.0,
-        major_radius=450,
-        minor_radius=150,
+        major_radius=450.0,
+        minor_radius=150.0,
         triangularity=0.55,
-        vertical_displacement=0,
+        vertical_displacement=0.0,
         num_points=50,
         configuration="non-null",
         x_point_shift=0.1,
@@ -73,37 +45,15 @@ class Plasma(RotateSplineShape):
         material_tag="DT_plasma",
         stp_filename="plasma.stp",
         stl_filename="plasma.stl",
-        color=(0.5, 0.5, 0.5),
-        rotation_angle=360,
-        azimuth_placement_angle=0,
         **kwargs
     ):
 
-        default_dict = {
-            "points": None,
-            "workplane": "XZ",
-            "solid": None,
-            "intersect": None,
-            "cut": None,
-            "union": None,
-            "tet_mesh": None,
-            "physical_groups": None,
-        }
-
-        for arg in kwargs:
-            if arg in default_dict:
-                default_dict[arg] = kwargs[arg]
-
         super().__init__(
             name=name,
-            color=color,
             material_tag=material_tag,
             stp_filename=stp_filename,
             stl_filename=stl_filename,
-            azimuth_placement_angle=azimuth_placement_angle,
-            rotation_angle=rotation_angle,
-            hash_value=None,
-            **default_dict
+            **kwargs
         )
 
         # properties needed for plasma shapes
@@ -120,17 +70,68 @@ class Plasma(RotateSplineShape):
         self.inner_equatorial_point = None
         self.high_point = None
         self.low_point = None
-        self.lower_x_point, self.upper_x_point = self.compute_x_points()
 
-    # overwrite points setter in Shape (error returned if not overwritten)
     @property
-    def points(self):
-        self.find_points()
-        return self._points
+    def high_point(self):
+        self.high_point = (
+            self.major_radius - self.triangularity * self.minor_radius,
+            self.elongation * self.minor_radius + self.vertical_displacement,
+        )
+        return self._high_point
 
-    @points.setter
-    def points(self, value):
-        self._points = value
+    @high_point.setter
+    def high_point(self, value):
+        self._high_point = value
+
+    @property
+    def low_point(self):
+        self.low_point = (
+            self.major_radius - self.triangularity * self.minor_radius,
+            -self.elongation * self.minor_radius + self.vertical_displacement,
+        )
+        return self._low_point
+
+    @low_point.setter
+    def low_point(self, value):
+        self._low_point = value
+
+    @property
+    def outer_equatorial_point(self):
+        self.outer_equatorial_point = (
+            self.major_radius + self.minor_radius, self.vertical_displacement)
+        return self._outer_equatorial_point
+
+    @outer_equatorial_point.setter
+    def outer_equatorial_point(self, value):
+        self._outer_equatorial_point = value
+
+    @property
+    def inner_equatorial_point(self):
+        self.inner_equatorial_point = (
+            self.major_radius - self.minor_radius, self.vertical_displacement)
+        return self._inner_equatorial_point
+
+    @inner_equatorial_point.setter
+    def inner_equatorial_point(self, value):
+        self._inner_equatorial_point = value
+
+    @property
+    def lower_x_point(self):
+        self.compute_x_points()
+        return self._lower_x_point
+
+    @lower_x_point.setter
+    def lower_x_point(self, value):
+        self._lower_x_point = value
+
+    @property
+    def upper_x_point(self):
+        self.compute_x_points()
+        return self._upper_x_point
+
+    @upper_x_point.setter
+    def upper_x_point(self, value):
+        self._upper_x_point = value
 
     @property
     def vertical_displacement(self):
@@ -146,7 +147,7 @@ class Plasma(RotateSplineShape):
 
     @minor_radius.setter
     def minor_radius(self, value):
-        if value > 2000 or value < 1:
+        if value < 1:
             raise ValueError("minor_radius is out of range")
         else:
             self._minor_radius = value
@@ -157,7 +158,7 @@ class Plasma(RotateSplineShape):
 
     @major_radius.setter
     def major_radius(self, value):
-        if value > 2000 or value < 1:
+        if value < 1:
             raise ValueError("major_radius is out of range")
         else:
             self._major_radius = value
@@ -175,17 +176,17 @@ class Plasma(RotateSplineShape):
 
     def compute_x_points(self):
         """Computes the location of X points based on plasma parameters and
-         configuration
+        configuration
 
         Returns:
             ((float, float), (float, float)): lower and upper x points
-             coordinates. None if no x points
+            coordinates. None if no x points
         """
         lower_x_point, upper_x_point = None, None  # non-null config
         shift = self.x_point_shift
         elongation = self.elongation
         triangularity = self.triangularity
-        if self.configuration == "single-null" or self.configuration == "double-null":
+        if self.configuration in ["single-null", "double-null"]:
             # no X points for non-null config
             lower_x_point = (1 -
                              (1 +
@@ -205,13 +206,14 @@ class Plasma(RotateSplineShape):
                     (1 + shift) * elongation * self.minor_radius
                     + self.vertical_displacement,
                 )
-        return lower_x_point, upper_x_point
+        self.lower_x_point = lower_x_point
+        self.upper_x_point = upper_x_point
 
     def find_points(self):
         """Finds the XZ points that describe the 2D profile of the plasma."""
 
         # create array of angles theta
-        theta = np.linspace(0, 2 * np.pi, num=self.num_points)
+        theta = np.linspace(0, 2 * np.pi, num=self.num_points, endpoint=False)
 
         # parametric equations for plasma
         def R(theta):
@@ -225,25 +227,4 @@ class Plasma(RotateSplineShape):
                 + self.vertical_displacement
             )
 
-        # R and Z coordinates
-        R_points, Z_points = R(theta), Z(theta)
-
-        # create a 2D array for points coordinates
-        points = np.stack((R_points, Z_points), axis=1)
-
-        # set self.points
-        self.points = list(points)
-
-        # set the points of interest
-        self.high_point = (
-            self.major_radius - self.triangularity * self.minor_radius,
-            self.elongation * self.minor_radius,
-        )
-        self.low_point = (
-            self.major_radius - self.triangularity * self.minor_radius,
-            -self.elongation * self.minor_radius,
-        )
-        self.outer_equatorial_point = (
-            self.major_radius + self.minor_radius, 0)
-        self.inner_equatorial_point = (
-            self.major_radius - self.minor_radius, 0)
+        self.points = np.stack((R(theta), Z(theta)), axis=1).tolist()
