@@ -33,8 +33,7 @@ class BallReactor(paramak.Reactor):
         elongation: the elongation of the plasma
         triangularity: the triangularity of the plasma
         plasma_gap_vertical_thickness: the vertical thickness of the gap
-            between the plasma and firstwall (cm). If left as None then the
-            outer_plasma_gap_radial_thickness is used.
+            between the plasma and firstwall (cm).
         divertor_to_tf_gap_vertical_thickness: the vertical thickness of the
             gap between the divertor and the TF coils.
         number_of_tf_coils: the number of tf coils
@@ -77,7 +76,7 @@ class BallReactor(paramak.Reactor):
             blanket_rear_wall_radial_thickness: float,
             elongation: float,
             triangularity: float,
-            plasma_gap_vertical_thickness: Optional[float] = None,
+            plasma_gap_vertical_thickness: float,
             divertor_to_tf_gap_vertical_thickness: Optional[float] = 0,
             number_of_tf_coils: Optional[int] = 12,
             rear_blanket_to_tf_gap: Optional[float] = None,
@@ -125,25 +124,6 @@ class BallReactor(paramak.Reactor):
 
         self.plasma_gap_vertical_thickness = plasma_gap_vertical_thickness
         self.divertor_to_tf_gap_vertical_thickness = divertor_to_tf_gap_vertical_thickness
-        if self.plasma_gap_vertical_thickness is None:
-            self.plasma_gap_vertical_thickness = \
-                self.outer_plasma_gap_radial_thickness
-        # sets major radius and minor radius from equatorial_points to allow a
-        # radial build
-        # this helps avoid the plasma overlapping the center column and other
-        # components
-
-        inner_equatorial_point = (
-            inner_bore_radial_thickness
-            + inboard_tf_leg_radial_thickness
-            + center_column_shield_radial_thickness
-            + inner_plasma_gap_radial_thickness
-        )
-        outer_equatorial_point = \
-            inner_equatorial_point + plasma_radial_thickness
-        self.major_radius = \
-            (outer_equatorial_point + inner_equatorial_point) / 2
-        self.minor_radius = self.major_radius - inner_equatorial_point
 
         self.elongation = elongation
         self.triangularity = triangularity
@@ -151,12 +131,38 @@ class BallReactor(paramak.Reactor):
         self.number_of_tf_coils = number_of_tf_coils
         self.rotation_angle = rotation_angle
 
-        self.offset_from_plasma = [
-            self.major_radius - self.minor_radius,
-            self.plasma_gap_vertical_thickness,
-            self.outer_plasma_gap_radial_thickness,
-            self.plasma_gap_vertical_thickness,
-            self.major_radius - self.minor_radius]
+        # adds self.input_variable_names from the Reactor class
+        self.input_variable_names = self.input_variable_names + [
+            'inner_bore_radial_thickness',
+            'inboard_tf_leg_radial_thickness',
+            'center_column_shield_radial_thickness',
+            'divertor_radial_thickness',
+            'inner_plasma_gap_radial_thickness',
+            'plasma_radial_thickness',
+            'outer_plasma_gap_radial_thickness',
+            'firstwall_radial_thickness',
+            'blanket_radial_thickness',
+            'blanket_rear_wall_radial_thickness',
+            'elongation',
+            'triangularity',
+            'plasma_gap_vertical_thickness',
+            'divertor_to_tf_gap_vertical_thickness',
+            'number_of_tf_coils',
+            'rear_blanket_to_tf_gap',
+            'pf_coil_radial_thicknesses',
+            'pf_coil_vertical_thicknesses',
+            'pf_coil_radial_position',
+            'pf_coil_vertical_position',
+            'pf_coil_case_thicknesses',
+            'outboard_tf_coil_radial_thickness',
+            'outboard_tf_coil_poloidal_thickness',
+            'divertor_position',
+            'rotation_angle',
+        ]
+
+        # set by make_plasma
+        self.major_radius = None
+        self.minor_radius = None
 
     @property
     def rotation_angle(self):
@@ -255,6 +261,21 @@ class BallReactor(paramak.Reactor):
 
     def _make_plasma(self):
 
+        inner_equatorial_point = (
+            self.inner_bore_radial_thickness
+            + self.inboard_tf_leg_radial_thickness
+            + self.center_column_shield_radial_thickness
+            + self.inner_plasma_gap_radial_thickness
+        )
+        outer_equatorial_point = inner_equatorial_point + self.plasma_radial_thickness
+
+        # sets major radius and minor radius from equatorial_points to allow a
+        # radial build. This helps avoid the plasma overlapping the center
+        # column and other components
+        self.major_radius = (outer_equatorial_point +
+                             inner_equatorial_point) / 2
+        self.minor_radius = self.major_radius - inner_equatorial_point
+
         plasma = paramak.Plasma(
             major_radius=self.major_radius,
             minor_radius=self.minor_radius,
@@ -373,6 +394,14 @@ class BallReactor(paramak.Reactor):
 
     def _make_blankets_layers(self):
 
+        offset_from_plasma = [
+            self.major_radius - self.minor_radius,
+            self.plasma_gap_vertical_thickness,
+            self.outer_plasma_gap_radial_thickness,
+            self.plasma_gap_vertical_thickness,
+            self.major_radius - self.minor_radius
+        ]
+
         self._center_column_cutter = paramak.CenterColumnShieldCylinder(
             # extra 0.5 to ensure overlap,
             height=self._center_column_shield_height * 1.5,
@@ -385,7 +414,7 @@ class BallReactor(paramak.Reactor):
         self._firstwall = paramak.BlanketFP(
             plasma=self._plasma,
             thickness=self.firstwall_radial_thickness,
-            offset_from_plasma=self.offset_from_plasma,
+            offset_from_plasma=offset_from_plasma,
             start_angle=-180,
             stop_angle=180,
             rotation_angle=self.rotation_angle,
@@ -401,7 +430,7 @@ class BallReactor(paramak.Reactor):
             plasma=self._plasma,
             thickness=self.blanket_radial_thickness,
             offset_from_plasma=[e + self.firstwall_radial_thickness
-                                for e in self.offset_from_plasma],
+                                for e in offset_from_plasma],
             start_angle=-180,
             stop_angle=180,
             rotation_angle=self.rotation_angle,
@@ -417,7 +446,7 @@ class BallReactor(paramak.Reactor):
             thickness=self.blanket_rear_wall_radial_thickness,
             offset_from_plasma=[e + self.firstwall_radial_thickness
                                 + self.blanket_radial_thickness
-                                for e in self.offset_from_plasma],
+                                for e in offset_from_plasma],
             start_angle=-180,
             stop_angle=180,
             rotation_angle=self.rotation_angle,
@@ -432,13 +461,22 @@ class BallReactor(paramak.Reactor):
         return [self._firstwall, self._blanket, self._blanket_rear_wall]
 
     def _make_divertor(self):
-        # # used as an intersect when making the divertor
+
+        offset_from_plasma = [
+            self.major_radius - self.minor_radius,
+            self.plasma_gap_vertical_thickness,
+            self.outer_plasma_gap_radial_thickness,
+            self.plasma_gap_vertical_thickness,
+            self.major_radius - self.minor_radius
+        ]
+
+        # used as an intersect when making the divertor
         self._blanket_fw_rear_wall_envelope = paramak.BlanketFP(
             plasma=self._plasma,
             thickness=self.firstwall_radial_thickness +
             self.blanket_radial_thickness +
             self.blanket_rear_wall_radial_thickness,
-            offset_from_plasma=self.offset_from_plasma,
+            offset_from_plasma=offset_from_plasma,
             start_angle=-180,
             stop_angle=180,
             rotation_angle=self.rotation_angle,
