@@ -84,21 +84,27 @@ class CenterColumnStudyReactor(paramak.Reactor):
         self.elongation = elongation
         self.triangularity = triangularity
 
-        # sets major radius and minor radius from equatorial_points to allow a
-        # radial build this helps avoid the plasma overlapping the center
-        # column and other components
+        # adds self.input_variable_names from the Reactor class
+        self.input_variable_names = self.input_variable_names + [
+            'inner_bore_radial_thickness',
+            'inboard_tf_leg_radial_thickness',
+            'center_column_shield_radial_thickness_mid',
+            'center_column_shield_radial_thickness_upper',
+            'inboard_firstwall_radial_thickness',
+            'divertor_radial_thickness',
+            'inner_plasma_gap_radial_thickness',
+            'plasma_radial_thickness',
+            'outer_plasma_gap_radial_thickness',
+            'center_column_arc_vertical_thickness',
+            'elongation',
+            'triangularity',
+            'plasma_gap_vertical_thickness',
+            'rotation_angle',
+        ]
 
-        inner_equatorial_point = (
-            inner_bore_radial_thickness
-            + inboard_tf_leg_radial_thickness
-            + center_column_shield_radial_thickness_mid
-            + inner_plasma_gap_radial_thickness
-        )
-        outer_equatorial_point = \
-            inner_equatorial_point + plasma_radial_thickness
-        self.major_radius = \
-            (outer_equatorial_point + inner_equatorial_point) / 2
-        self.minor_radius = self.major_radius - inner_equatorial_point
+        # set by make_plasma
+        self.major_radius = None
+        self.minor_radius = None
 
     def create_solids(self):
         """Creates a 3d solids for each component.
@@ -130,6 +136,22 @@ class CenterColumnStudyReactor(paramak.Reactor):
 
     def _make_plasma(self):
 
+        # sets major radius and minor radius from equatorial_points to allow a
+        # radial build this helps avoid the plasma overlapping the center
+        # column and other components
+
+        inner_equatorial_point = (
+            self.inner_bore_radial_thickness
+            + self.inboard_tf_leg_radial_thickness
+            + self.center_column_shield_radial_thickness_mid
+            + self.inner_plasma_gap_radial_thickness
+        )
+        outer_equatorial_point = \
+            inner_equatorial_point + self.plasma_radial_thickness
+        self.major_radius = \
+            (outer_equatorial_point + inner_equatorial_point) / 2
+        self.minor_radius = self.major_radius - inner_equatorial_point
+
         plasma = paramak.Plasma(
             major_radius=self.major_radius,
             minor_radius=self.minor_radius,
