@@ -27,6 +27,12 @@ class EuDemoFrom2015PaperDiagram(paramak.Reactor):
         self.rotation_angle = rotation_angle
         self.number_of_tf_coils = number_of_tf_coils
 
+        # adds self.input_variable_names from the Reactor class
+        self.input_variable_names = self.input_variable_names + [
+            'number_of_tf_coils',
+            'rotation_angle',
+        ]
+
     def create_tf_coils(self, vac_vessel_inner, vac_vessel) -> list:
         """Creates a 3d solids for each tf coil.
 
