@@ -25,7 +25,7 @@ class TestCuttingWedge(unittest.TestCase):
             )
             angle_fraction = 360 / rotation_angle
             correct_volume = (math.pi * radius ** 2 * height) / angle_fraction
-            assert test_shape.volume == pytest.approx(correct_volume)
+            assert test_shape.volume() == pytest.approx(correct_volume)
 
     def test_surface_reflectivity_in_neutronics_description(self):
         test_shape = paramak.CuttingWedge(
@@ -35,6 +35,6 @@ class TestCuttingWedge(unittest.TestCase):
             surface_reflectivity=True
         )
 
-        json_dict = test_shape.neutronics_description()
+        json_dict = test_shape.neutronics_description()[0]
         assert 'surface_reflectivity' in json_dict.keys()
         assert json_dict['surface_reflectivity'] is True
